@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        ext/pperl/splashfast/SplashFast.pm
+## Name:        SplashFast.pm
 ## Purpose:     Wx::Perl::SplashFast -> Show a splash before loading Wx.
 ## Author:      Graciliano M. P.
 ## Modified by:
 ## Created:     30/06/2002
-## RCS-ID:      $Id: SplashFast.pm,v 1.21.2.2 2005/08/18 16:12:24 mbarbon Exp $
-## Copyright:   (c) 2002-2005 Graciliano M. P.
+## RCS-ID:      
+## Copyright:   (c) 2002 Graciliano M. P.
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -15,7 +15,7 @@ use strict;
 package Wx::Perl::SplashFast ;
 use vars qw($VERSION) ;
 
-$VERSION = '0.02'; # for wxPerl 0.15+
+$VERSION = '0.01'; # for wxPerl 0.11+
 
 sub import {
   Wx::Perl::SplashFast::new(@_) if @_ > 1;
@@ -30,7 +30,7 @@ sub new {
   my $any = Wx::constant( 'wxBITMAP_TYPE_ANY', 0 );
   my $spl_c = Wx::constant( 'wxSPLASH_CENTRE_ON_SCREEN', 0 );
   my $spl_ti = Wx::constant( 'wxSPLASH_TIMEOUT', 0 );
-  my $bitmap = Wx::Bitmap->new( $_[0], $any );
+  my $bitmap = Wx::Bitmap::newFile( $_[0], $any );
 
   my $splash = Wx::SplashScreen->new( $bitmap , $spl_c|$spl_ti ,
                                       $_[1] || 1000 , undef , -1 );
@@ -60,16 +60,12 @@ sub OnInit { return 1 }
 
 package Wx ;
 
-use vars qw($VERSION $XS_VERSION);
+use vars qw($VERSION);
 
-$VERSION = '0.25_01'; # bootstrap will catch wrong versions
-$XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
+$VERSION = '0.11'; # bootstrap will catch wrong versions
 
 sub wxPL_STATIC();
 sub _wx_boot($$) {
-  local $ENV{PATH} = 'XXXALIENXXX' . $ENV{PATH} if $^O eq 'MSWin32';
-
   if( $_[0] eq 'Wx' ) {
     if( $] < 5.006 ) {
       require DynaLoader;
@@ -87,12 +83,32 @@ sub _wx_boot($$) {
   }
 }
 
-_wx_boot( 'Wx', $XS_VERSION );
-_boot_Constant( 'Wx', $XS_VERSION );
-_boot_GDI( 'Wx', $XS_VERSION );
+_wx_boot( 'Wx', $VERSION );
+
+_boot_Constant( 'Wx', $VERSION );
+_boot_GDI( 'Wx', $VERSION );
 
 Load();
 
+####################
+# WX::SPLASHSCREEN #
+####################
+
+package Wx::Frame; # package needs to exist, since we put it in @ISA
+package Wx::SplashScreen;
+
+use vars qw(@ISA); @ISA = qw(Wx::_SplashScreenCpp);
+
+# check wxWindows version, since the C++ implementation of
+# Wx::SplashScreen is only available for wxWindows 2.3.x
+if( $Wx::_wx_version < 2.003 && $Wx::_wx_version > 0 ) {
+  require Carp;
+  Carp::croak( "You are using wxPerl with wxWindows $Wx::_wx_version. You need wxPerl (0.11+) compiled against wxWindows 2.3!" );
+}
+
+package Wx::_SplashScreenCpp;
+use vars qw(@ISA) ; @ISA = qw(Wx::Frame) ;
+
 #######
 # END #
 #######
@@ -217,6 +233,11 @@ Timeout of the splash screen in milliseconds.
   $myApp->SetTopWindow( $win ) ;
   $myApp->MainLoop();
 
+=head1 NOTE
+
+This package only works if wxPerl has been compiled against
+wxWindows 2.3.x.
+
 =head1 SEE ALSO
 
 L<Wx>, L<Wx:SplashScreen>
@@ -224,7 +245,7 @@ L<Wx>, L<Wx:SplashScreen>
 =head1 AUTHOR
 
 Graciliano M. P. <gm@virtuasites.com.br>
-Thanks to wxWidgets people and Mattia Barbon for wxPerl! :P
+Thanks to wxWindows peoples and Mattia Barbon for wxPerl! :P
 
 =head1 COPYRIGHT
 
