@@ -13,7 +13,6 @@
 package Wx::Pen;
 
 use strict;
-use Carp;
 
 my( $wcol_i_i ) = [ 'Wx::Colour', 'INTEGER', 'INTEGER' ];
 my( $s_i_i ) = [ '?', 'INTEGER', 'INTEGER' ];
@@ -25,7 +24,7 @@ sub new {
   Wx::_match( @_, $Wx::wcol_n_n, 3 ) && return Wx::Pen::newColour( @_ );
   Wx::_match( @_, $Wx::wbmp_n, 2 )   && return Wx::Pen::newBitmap( @_ );
   Wx::_match( @_, $Wx::s_n_n, 3 )    && return Wx::Pen::newString( @_ );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 sub SetColour {
@@ -34,7 +33,7 @@ sub SetColour {
   Wx::_match( @_, $Wx::_wcol, 1 )  && ( $this->SetColourColour( @_ ), return );
   Wx::_match( @_, $Wx::_n_n_n, 3 ) && ( $this->SetColourRGB( @_ ), return );
   Wx::_match( @_, $Wx::_s, 1 )     && ( $this->SetColourName( @_ ), return );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 1;
