@@ -13,7 +13,6 @@
 package Wx::RadioBox;
 
 use strict;
-use Carp;
 
 if( $Wx::_platform == $Wx::_gtk ) {
   @Wx::RadioBox::ISA = qw(Wx::Control);
@@ -27,7 +26,7 @@ sub Enable {
 
   Wx::_match( @_, $Wx::_b, 1 )   && ( $this->SUPER::Enable( @_ ), return );
   Wx::_match( @_, $Wx::_n_b, 2 ) && ( $this->EnableItem( @_ ), return );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 sub GetLabel {
@@ -35,7 +34,7 @@ sub GetLabel {
 
   @_ == 0                  && return $this->SUPER::GetLabel();
   Wx::_match( @_, $Wx::_n, 1 ) && return $this->GetItemLabel();
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 sub SetLabel {
@@ -43,7 +42,7 @@ sub SetLabel {
 
   Wx::_match( @_, $Wx::_n_s, 2 ) && $this->SetItemLabel( @_ );
   Wx::_match( @_, $Wx::_s, 1 )   && $this->SUPER::SetLabel( @_ );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 sub Show {
@@ -51,7 +50,7 @@ sub Show {
 
   Wx::_match( @_, $Wx::_n_n, 2 ) && $this->ShowItem( @_ );
   Wx::_match( @_, $Wx::_n, 1 )   && $this->Show( @_ );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 1;
