@@ -13,13 +13,12 @@
 package Wx::StaticBitmap;
 
 use strict;
-use Carp;
 
 sub new {
   Wx::_match( @_, $Wx::_s_wwin_n_wico, 3, 1 ) && return Wx::StaticBitmap::newIcon( @_ );
   Wx::_match( @_, $Wx::_s_wwin_n_wbmp, 3, 1 ) &&
       return Wx::StaticBitmap::newBitmap( @_ );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 1;
