@@ -13,7 +13,6 @@
 package Wx::ToolBar;
 
 use strict;
-use Carp;
 
 sub AddTool {
   my( $this ) = shift;
@@ -21,7 +20,7 @@ sub AddTool {
   Wx::_match( @_, $Wx::_n_wbmp_wbmp_b_s_s_s, 2, 1 ) && return $this->AddToolLong( @_ );
   Wx::_match( @_, $Wx::_n_wbmp_s_s, 2, 1 )          && return $this->AddToolShort( @_ );
 
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 sub SetMargins {
@@ -29,7 +28,7 @@ sub SetMargins {
 
   Wx::_match( @_, $Wx::_n_n, 2 )  && ( $this->SetMarginsXY( @_ ), return );
   Wx::_match( @_, $Wx::_wsiz, 1 ) && ( $this->SetMarginsSize( @_ ), return );
-  croak Wx::_ovl_error;
+  Wx::_croak Wx::_ovl_error;
 }
 
 1;
